@@ -1,5 +1,5 @@
 package Pithub;
-$Pithub::VERSION = '0.01030';
+$Pithub::VERSION = '0.01031';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 API
@@ -108,7 +108,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01030
+version 0.01031
 
 =head1 SYNOPSIS
 
@@ -116,6 +116,7 @@ version 0.01030
     use Data::Dumper;
 
     my $p = Pithub->new;
+    # my $p = Pithub->new(utf8 => 0); # enable compatibility options for version 0.01029 or lower
     my $result = $p->repos->get( user => 'plu', repo => 'Pithub' );
 
     # $result->content is either an arrayref or an hashref
@@ -134,9 +135,19 @@ version 0.01030
         api_uri => 'https://github.yourdomain.com/api/v3/'
     );
 
+    # No need to provide user/repo to each module:
+    my $pit = Pithub->new(
+      user  => $user,
+      repo  => $repo,
+      token => $oauth_token,
+    );
+
+    $pit->repos->get;
+    $pit->repos->commits->list;
+
 =head1 DESCRIPTION
 
-L<Pithub> provides a set of modules to access the
+L<Pithub> (B<P>erl + GB<ithub>) provides a set of modules to access the
 L<Github v3 API|http://developer.github.com/v3/> in an object
 oriented way. There is also L<Net::GitHub> which does the same for
 all the versions (v1, v2, v3) of the Github API.
@@ -205,6 +216,9 @@ L<Github|http://developer.github.com/v3/>. Please also read the
 documentation there, since it might be more complete and more
 up-to-date.
 
+L<Pithub::Base> contains documentation for attributes inherited by all
+Pithub modules.
+
 =head1 WARNING
 
 L<Pithub> as well as the
@@ -264,8 +278,8 @@ L<Pithub::Events>
 
 See also: L<http://developer.github.com/v3/events/>
 
-    my $gists = Pithub->new->events;
-    my $gists = Pithub::Events->new;
+    my $events = Pithub->new->events;
+    my $events = Pithub::Events->new;
 
 =item *
 
