@@ -1,5 +1,5 @@
 package Pithub::Base;
-$Pithub::Base::VERSION = '0.01030';
+$Pithub::Base::VERSION = '0.01031';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 base class for all Pithub modules
@@ -87,6 +87,12 @@ has 'user' => (
     required  => 0,
 );
 
+
+has 'utf8' => (
+    is      => 'ro',
+    default => 1,
+);
+
 has '_json' => (
     builder => '_build__json',
     is      => 'ro',
@@ -240,6 +246,7 @@ sub request {
     return Pithub::Result->new(
         auto_pagination => $self->auto_pagination,
         response        => $response,
+        utf8            => $self->utf8,
         _request        => sub { $self->request(@_) },
     );
 }
@@ -284,7 +291,7 @@ sub has_token {
 
 sub _build__json {
     my ($self) = @_;
-    return JSON->new->utf8;
+    return JSON->new->utf8($self->utf8);
 }
 
 sub _build_ua {
@@ -405,7 +412,7 @@ Pithub::Base - Github v3 base class for all Pithub modules
 
 =head1 VERSION
 
-version 0.01030
+version 0.01031
 
 =head1 DESCRIPTION
 
@@ -697,6 +704,15 @@ It might make sense to use this together with the repo attribute:
     my $result = $c->list_comments;
     my $result = $c->get('6b6127383666e8ecb41ec20a669e4f0552772363');
 
+=head2 utf8
+
+This can set utf8 flag.
+
+Examples:
+
+    my $p = Pithub->new(utf8 => 0); # disable utf8 en/decoding
+    my $p = Pithub->new(utf8 => 1); # enable utf8 en/decoding (default)
+
 =head1 METHODS
 
 =head2 request
