@@ -1,5 +1,5 @@
 package Pithub::Result;
-$Pithub::Result::VERSION = '0.01030';
+$Pithub::Result::VERSION = '0.01031';
 our $AUTHORITY = 'cpan:PLU';
 
 # ABSTRACT: Github v3 result object
@@ -97,6 +97,12 @@ has '_iterator' => (
     lazy    => 1,
 );
 
+
+has 'utf8' => (
+    is      => 'ro',
+    default => 1,
+);
+
 has '_json' => (
     builder => '_build__json',
     is      => 'ro',
@@ -253,7 +259,7 @@ sub _build_prev_page_uri {
 
 sub _build__json {
     my ($self) = @_;
-    return JSON->new->utf8;
+    return JSON->new->utf8($self->utf8);
 }
 
 sub _get_link_header {
@@ -312,7 +318,7 @@ Pithub::Result - Github v3 result object
 
 =head1 VERSION
 
-version 0.01030
+version 0.01031
 
 =head1 DESCRIPTION
 
@@ -384,6 +390,10 @@ page. This can return undef.
 
 The L<HTTP::Response> object.
 
+=head2 utf8
+
+This can set utf8 flag.
+
 =head1 METHODS
 
 =head2 raw_content
